@@ -9,7 +9,7 @@ import f61d.LOGO as LOGO
 from math import ceil
 from tqdm import *
 
-VERSION = (0,4,1)
+VERSION = (0,4,2)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -240,5 +240,7 @@ def mtank(outPic,innerPic,output='tank.png'):
         print('')
         raise
     p1 = img.open(outPic)
+    p1 = p1.convert('L')
     p2 = img.open(innerPic)
+    p2- = p2.convert('L')
     make(p1,p2,output)
